library("plyr")
library("ggplot2")

RT <- read.table(file="RT_qPCR_Tub4Dup_raw.csv", header=T, sep=",")

# remove controls and dilution series
RT.Dil <- split(RT, RT$Sample.Type)[["Dilution Series"]]
RT.Samp <- split(RT, RT$Sample.Type)[["Sample"]]
RT.Samp$Standard <- NULL
RT.Samp$Strain <- factor(rep(c("ESM356", "FHY150"), each=10))
RT.Samp$Genotype <- ifelse ( RT.Samp$Strain %in% c("ESM356"),  "wild type", "duplication" )
RT.Samp$Genotype <- factor(RT.Samp$Genotype, levels=c("wild type", "duplication"))
# add SD
RT.Samp <- ddply(RT.Samp, .(Amplicon, cDNA.or.gDNA, Genotype), function (x) {x$Cp.SD <- sd(x$Cp); return(x)} )

# Roche LightCycler Software returned the following efficiencies:
# TUB4: cDNA dilution series: 1.948
# TUB4: gDNA dilution series: 1.977
# Actin: cDNA: 1.981
# Actin: gDNA: 1.954
RT.Samp$Eff <- rep(c(1.981, 1.954, 1.948, 1.977), each=10)
RT.Samp$Conc <- 1/(RT.Samp$Eff^(RT.Samp$Cp))

RT.Samp <- ddply(RT.Samp, .(Amplicon, cDNA.or.gDNA, Genotype), function (x) {
   x$Conc.SD <- sd(x$Conc); return(x)} )
RT.Samp <- ddply(RT.Samp, .(cDNA.or.gDNA, Genotype), function(x) {
   x$Conc.Norm <- x$Conc/mean(x$Conc[x$Amplicon=="Actin"]); return(x)})
# test significances for cDNA and gDNA
with(RT.Samp, t.test(RT.Samp$Conc.Norm[cDNA.or.gDNA=="cDNA" & Genotype=="wild type" & Amplicon=="TUB4"],
                     RT.Samp$Conc.Norm[cDNA.or.gDNA=="cDNA" & Genotype=="duplication" & Amplicon=="TUB4"]))

with(RT.Samp, t.test(RT.Samp$Conc.Norm[cDNA.or.gDNA=="gDNA" & Genotype=="wild type" & Amplicon=="TUB4"],
                     RT.Samp$Conc.Norm[cDNA.or.gDNA=="gDNA" & Genotype=="duplication" & Amplicon=="TUB4"]))


# test significance for gDNA

RT.Samp.Avg <- ddply(RT.Samp, .(Amplicon, cDNA.or.gDNA, Genotype), numcolwise(mean))

# normalise concentrations to actin
RT.Samp.Avg <- ddply(RT.Samp.Avg, .(cDNA.or.gDNA, Genotype), function(x) {
   x$Conc.Norm <- x$Conc/x$Conc[x$Amplicon=="Actin"]; return(x)})

# normalise SDs to actin
RT.Samp.Avg <- ddply(RT.Samp.Avg, .(cDNA.or.gDNA, Genotype), function(x) {
   x$Conc.SD.Norm <- x$Conc.SD/x$Conc[x$Amplicon=="Actin"]; return(x)})

# and now normalise to wild type
RT.Samp.Avg <- ddply(RT.Samp.Avg, .(cDNA.or.gDNA, Amplicon), function(x) {
   x$Conc.NormToWt <- x$Conc.Norm/x$Conc.Norm[x$Genotype=="wild type"]; return(x)})

RT.Samp.Avg <- ddply(RT.Samp.Avg, .(cDNA.or.gDNA, Amplicon), function(x) {
   x$Conc.SD.NormToWt <- x$Conc.SD.Norm/x$Conc.Norm[x$Genotype=="wild type"]; return(x)})

cDNA.avgs <- RT.Samp.Avg[RT.Samp.Avg$cDNA.or.gDNA=="cDNA" & RT.Samp.Avg$Amplicon=="TUB4", ]
gDNA.avgs <- RT.Samp.Avg[RT.Samp.Avg$cDNA.or.gDNA=="gDNA" & RT.Samp.Avg$Amplicon=="TUB4", ]
Tub4.avgs <- RT.Samp.Avg[RT.Samp.Avg$Amplicon=="TUB4", ]

limits <- aes(ymax = Tub4.avgs$Conc.NormToWt + Tub4.avgs$Conc.SD.NormToWt, 
              ymin = Tub4.avgs$Conc.NormToWt - Tub4.avgs$Conc.SD.NormToWt)
Tub4.plot <- 
    ggplot(data=Tub4.avgs, aes(x=Genotype, y=Conc.NormToWt)) + 
    facet_grid(. ~ cDNA.or.gDNA) +
    geom_bar(stat="identity") +
    geom_errorbar(limits, width=0.10) +
    theme_bw(base_size=14) +
    labs(y="Relative cDNA/gDNA amounts", title="qPCR Results 02.05.2014")
Tub4.plot
